==> flask-inertia-0.4.tar.gz: flask-inertia-0.4/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# MIT License
#
# Copyright (c) 2021 TROUVERIE Joachim <jtrouverie@joakode.fr>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
flask-inertia
-------------

InertiaJS adapter for Flask.
"""

import os
from typing import List

from setuptools import find_packages, setup

from flask_inertia import __version__

__author__ = "TROUVERIE Joachim"
__contact__ = "jtrouverie@joakode.fr"


def read_requirement_file(filename: str) -> List[str]:
    filepath = os.path.join(os.path.abspath(os.path.dirname(__file__)), filename)
    with open(filepath, "r") as fi:
        requirements = fi.read().split()

    return requirements


requirements = read_requirement_file("requirements.txt")
tests_requirements = read_requirement_file("tests_requirements.txt")


setup(
    name="flask-inertia",
    version=__version__,
    url="https://github.com/j0ack/flask-inertia",
    license="MIT",
    author=__author__,
    author_email=__contact__,
    description="Inertiajs Adapter for Flask.",
    include_package_data=True,
    long_description=open("README.rst").read(),
    packages=find_packages(include=["flask_inertia", "flask_inertia.*"]),
    zip_safe=False,
    platforms="any",
    install_requires=requirements,
    extras_require={"tests": tests_requirements},
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Framework :: Flask",
        "Programming Language :: Python :: 3",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Utilities",
    ],
)

==> flask-inertia-0.6.tar.gz: flask-inertia-0.6/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# MIT License
#
# Copyright (c) 2021 TROUVERIE Joachim <jtrouverie@joakode.fr>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""
flask-inertia
-------------

InertiaJS adapter for Flask.
"""

import os
from typing import List

from setuptools import find_packages, setup

from flask_inertia import __version__

__author__ = "TROUVERIE Joachim"
__contact__ = "jtrouverie@joakode.fr"


def read_requirement_file(filename: str) -> List[str]:  # noqa: D103
    filepath = os.path.join(os.path.abspath(os.path.dirname(__file__)), filename)
    with open(filepath, "r") as fi:
        requirements = fi.read().split()

    return requirements


requirements = read_requirement_file("requirements.txt")
tests_requirements = read_requirement_file("tests_requirements.txt")


setup(
    name="flask-inertia",
    version=__version__,
    url="https://github.com/j0ack/flask-inertia",
    license="MIT",
    author=__author__,
    author_email=__contact__,
    description="Inertiajs Adapter for Flask.",
    include_package_data=True,
    long_description=open("README.rst").read(),
    packages=find_packages(include=["flask_inertia", "flask_inertia.*"]),
    zip_safe=False,
    platforms="any",
    install_requires=requirements,
    extras_require={"tests": tests_requirements},
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Framework :: Flask",
        "Programming Language :: Python :: 3",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Utilities",
    ],
)
